@@ -33,6 +33,14 @@ sub query {
     return $self->{'query'};
 }
 
+#sub get_query {
+#    my ($self,$query) = @_;
+#    if (defined $query) {
+#	return $self->query($query);
+#    };
+#    return $self->query;
+#}
+
 sub message {
     my ($self,$msg) = @_;
     if (defined $msg) {
@@ -41,6 +49,8 @@ sub message {
     return $self->{'message'};
 }
 
+
+
 # Checks, wether the query returned some useful results or not. 
 # If not, one should check the error message via &get_message. 
 # Could be better, by checking deeper in the data structure,
@@ -51,6 +61,8 @@ sub isOK {
   return 0;
 };
 
+
+
 sub get_fees {
   my $self = shift;
   my $_frame = shift;
@@ -74,7 +86,7 @@ sub get_weights {
 };
 
 # not working
-sub get_delta {
+sub _get_delta {
   my $self = shift;
   my $frame = shift;
   
@@ -198,8 +210,8 @@ FrameNet::WordNet::Detour::Data - A class representing the results of the Detour
 
   my $result = $detour->query($synset);
 
-  $result->isOK;       # Returns whether there were problems in the run
-  $result->getMessage; # Returns 'Ok' or an error message
+  $result->is_ok;   # Returns whether there were problems in the run
+  $result->message; # Returns 'Ok' or an error message
 
   # All frames are returned as lists of 
   # L<FrameNet::WordNet::Detour::Frame> objects
@@ -272,6 +284,24 @@ Returns the overall number of frames found for this specific query:
 
 Returns a reference to a list of the frames with the given weight. You should notice, that you have to give the exact weight - e.g. like in the get_weights-array. Rounded values will not find anything.
 
+=item new ( )
+
+=item get_all_framenames 
+
+Returns a list containing all frame names.
+
+=item get_best_framenames N
+
+Returns a list of N highest weighted names of frames.
+
+=item get_best_weight
+
+Returns the highest weight
+
+=item isOK
+
+Returns true, if the data object is sober and clean
+
 =back
 
 =head1 BUGS
